cattr package
=============

Submodules
----------

cattr.converters module
-----------------------

.. automodule:: cattr.converters
   :members:
   :undoc-members:
   :show-inheritance:

cattr.disambiguators module
---------------------------

.. automodule:: cattr.disambiguators
   :members:
   :undoc-members:
   :show-inheritance:

cattr.function\_dispatch module
-------------------------------

.. automodule:: cattr.function_dispatch
   :members:
   :undoc-members:
   :show-inheritance:

cattr.gen module
----------------

.. automodule:: cattr.gen
   :members:
   :undoc-members:
   :show-inheritance:

cattr.multistrategy\_dispatch module
------------------------------------

.. automodule:: cattr.multistrategy_dispatch
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: cattr
   :members:
   :undoc-members:
   :show-inheritance:
